@@ -40,10 +40,6 @@ class FetchDET(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return FetchDET.defn()
