@@ -1,10 +1,10 @@
+#include "./validate.hpp"
+
 #include <cstdio>
 #include <cstring>
 #include <fstream>
 #include <sstream>
 
-#include "validate.hpp"
-
 int
 main (int argc, char **argv)
 {
