@@ -14,12 +14,10 @@
  * limitations under the License.
  */
 
+#include "./corpus-test.h"
 
 #include <bson/bson.h>
 
-#include "corpus-test.h"
-
-
 #ifdef _MSC_VER
 #define SSCANF sscanf_s
 #else
@@ -57,7 +55,6 @@ corpus_test_unhexlify (bson_iter_t *iter, uint32_t *bson_str_len)
    return data;
 }
 
-
 void
 corpus_test (bson_t *scenario,
              test_bson_valid_cb valid,
