@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,15 +14,16 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 
 #ifndef MONGOC_SCRAM_PRIVATE_H
 #define MONGOC_SCRAM_PRIVATE_H
 
 
+#include <mongoc/mongoc-crypto-private.h>
+
 #include <bson/bson.h>
-#include "mongoc-crypto-private.h"
 
 
 BSON_BEGIN_DECLS
