@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,15 +14,17 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_SECURE_TRANSPORT_PRIVATE_H
 #define MONGOC_SECURE_TRANSPORT_PRIVATE_H
 
+#include <mongoc/mongoc-stream-tls-secure-transport-private.h>
+
+#include <mongoc/mongoc-ssl.h>
+
 #include <bson/bson.h>
 
-#include "mongoc-ssl.h"
-#include "mongoc-stream-tls-secure-transport-private.h"
 #include <Security/Security.h>
 
 
@@ -31,9 +33,6 @@ BSON_BEGIN_DECLS
 char *
 _mongoc_cfstringref_to_cstring (CFStringRef ref);
 
-char *
-_mongoc_secure_transport_extract_subject (const char *filename, const char *passphrase);
-
 OSStatus
 mongoc_secure_transport_write (SSLConnectionRef connection, const void *data, size_t *data_length);
 OSStatus
