@@ -1,16 +1,17 @@
-#include <bson/bson.h>
-#include <errno.h>
-
 #include <mongoc/mongoc-config.h>
+
+#include <bson/bson.h>
+
+#include <errno.h>
 #ifdef MONGOC_ENABLE_SSL_OPENSSL
-#include <openssl/ssl.h>
 #include <openssl/err.h>
+#include <openssl/ssl.h>
 #endif
 
 #include <mongoc/mongoc-stream-tls.h>
 
-#include "ssl-test.h"
-#include "TestSuite.h"
+#include <TestSuite.h>
+#include <ssl-test.h>
 
 #define TIMEOUT 10 * 1000
 
