@@ -1,6 +1,7 @@
-#include <mongoc/mongoc.h>
 #include <mongoc/mongoc-ssl-private.h>
 
+#include <mongoc/mongoc.h>
+
 #ifdef MONGOC_ENABLE_SSL_OPENSSL
 #include <mongoc/mongoc-openssl-private.h>
 #endif
@@ -9,9 +10,9 @@
 #include <mongoc/mongoc-secure-channel-private.h>
 #endif
 
-#include "TestSuite.h"
-#include "test-libmongoc.h"
-#include "test-conveniences.h" // tmp_bson
+#include <TestSuite.h>
+#include <test-conveniences.h> // tmp_bson
+#include <test-libmongoc.h>
 
 #ifdef MONGOC_ENABLE_OCSP_OPENSSL
 /* Test parsing a DER encoded tlsfeature extension contents for the
@@ -135,6 +136,117 @@ try_insert (mongoc_client_t *client, bson_error_t *error)
    return ok;
 }
 
+#ifdef MONGOC_ENABLE_SSL_SECURE_CHANNEL
+// Define utilities check and delete imported keys for Secure Channel:
+
+// The deterministic name for the certificate in src/libmongoc/tests/x509gen/client-pkcs8-unencrypted.pem.
+static LPCWSTR pkcs8_key_name = L"libmongoc-6659E73980D0FB4EB315CF600E0B10CCBB8C3B74FD3ED94DEAF6DC2D2B6B8317-pkcs8";
+
+static void
+delete_imported_pkcs8_key (void)
+{
+   // Open the software key storage provider:
+   NCRYPT_PROV_HANDLE hProv = 0;
+   SECURITY_STATUS status = NCryptOpenStorageProvider (&hProv, MS_KEY_STORAGE_PROVIDER, 0);
+   ASSERT_WITH_MSG (status == SEC_E_OK, "Failed to open key storage provider: %s", mongoc_winerr_to_string (status));
+
+   // Open the key handle:
+   NCRYPT_PROV_HANDLE keyHandle = 0;
+   status = NCryptOpenKey (hProv, &keyHandle, pkcs8_key_name, 0, 0);
+   ASSERT_WITH_MSG (status == SEC_E_OK, "Failed to open key: %s", mongoc_winerr_to_string (status));
+
+   // Delete key:
+   status = NCryptDeleteKey (keyHandle, 0); // Also frees handle.
+   ASSERT_WITH_MSG (status == SEC_E_OK, "Failed to delete key: %s", mongoc_winerr_to_string (status));
+
+   // NCryptDeleteKey freed handle.
+   ASSERT (NCryptFreeObject (hProv) == ERROR_SUCCESS);
+}
+
+static bool
+has_imported_pkcs8_key (void)
+{
+   // Open the software key storage provider:
+   NCRYPT_PROV_HANDLE hProv = 0;
+   SECURITY_STATUS status = NCryptOpenStorageProvider (&hProv, MS_KEY_STORAGE_PROVIDER, 0);
+   ASSERT_WITH_MSG (status == SEC_E_OK, "Failed to open key storage provider: %s", mongoc_winerr_to_string (status));
+
+   // Open the key handle:
+   NCRYPT_PROV_HANDLE keyHandle = 0;
+   status = NCryptOpenKey (hProv, &keyHandle, pkcs8_key_name, 0, 0);
+   bool found = (status == SEC_E_OK);
+   // NTE_BAD_KEYSET is expected if key is not found.
+   ASSERT_WITH_MSG (
+      status == SEC_E_OK || status == NTE_BAD_KEYSET, "Failed to open key: %s", mongoc_winerr_to_string (status));
+
+   if (keyHandle) {
+      ASSERT (NCryptFreeObject (keyHandle) == ERROR_SUCCESS);
+   }
+   ASSERT (NCryptFreeObject (hProv) == ERROR_SUCCESS);
+   return found;
+}
+
+// The deterministic name for the certificate in src/libmongoc/tests/x509gen/client.pem.
+static LPCWSTR pkcs1_key_name = L"libmongoc-6659E73980D0FB4EB315CF600E0B10CCBB8C3B74FD3ED94DEAF6DC2D2B6B8317-pkcs1";
+
+static void
+delete_imported_pkcs1_key (void)
+{
+   HCRYPTPROV provider;
+   bool success = CryptAcquireContextW (&provider,                          /* phProv */
+                                        pkcs1_key_name,                     /* pszContainer */
+                                        MS_ENHANCED_PROV_W,                 /* pszProvider */
+                                        PROV_RSA_FULL,                      /* dwProvType */
+                                        CRYPT_DELETEKEYSET | CRYPT_SILENT); /* dwFlags */
+   ASSERT_WITH_MSG (success, "Failed to delete key: %s", mongoc_winerr_to_string (GetLastError ()));
+   // CRYPT_DELETEKEYSET leaves provider undefined. Do not call CryptReleaseContext.
+}
+
+static bool
+has_imported_pkcs1_key (void)
+{
+   HCRYPTPROV provider = 0;
+   bool success = CryptAcquireContextW (&provider,          /* phProv */
+                                        pkcs1_key_name,     /* pszContainer */
+                                        MS_ENHANCED_PROV_W, /* pszProvider */
+                                        PROV_RSA_FULL,      /* dwProvType */
+                                        CRYPT_SILENT);      /* dwFlags */
+   if (!success) {
+      const DWORD lastError = GetLastError ();
+      // NTE_BAD_KEYSET is expected if key is not found.
+      ASSERT_WITH_MSG (lastError == (DWORD) NTE_BAD_KEYSET,
+                       "Unexpected error in acquiring context: %s",
+                       mongoc_winerr_to_string (lastError));
+      return false;
+   }
+
+   ASSERT (CryptReleaseContext (provider, 0));
+   return true;
+}
+
+#define SCHANNEL_ASSERT_PKCS8_KEY_IMPORTED() ASSERT (has_imported_pkcs8_key ())
+#define SCHANNEL_ASSERT_PKCS8_KEY_NOT_IMPORTED() ASSERT (!has_imported_pkcs8_key ())
+#define SCHANNEL_DELETE_PKCS8_KEY() \
+   if (has_imported_pkcs8_key ())   \
+      delete_imported_pkcs8_key (); \
+   else                             \
+      (void) 0
+#define SCHANNEL_ASSERT_PKCS1_KEY_IMPORTED() ASSERT (has_imported_pkcs1_key ())
+#define SCHANNEL_ASSERT_PKCS1_KEY_NOT_IMPORTED() ASSERT (!has_imported_pkcs1_key ())
+#define SCHANNEL_DELETE_PKCS1_KEY() \
+   if (has_imported_pkcs1_key ())   \
+      delete_imported_pkcs1_key (); \
+   else                             \
+      (void) 0
+#else
+#define SCHANNEL_ASSERT_PKCS8_KEY_IMPORTED() ((void) 0)
+#define SCHANNEL_ASSERT_PKCS8_KEY_NOT_IMPORTED() ((void) 0)
+#define SCHANNEL_DELETE_PKCS8_KEY() ((void) 0)
+#define SCHANNEL_ASSERT_PKCS1_KEY_IMPORTED() ((void) 0)
+#define SCHANNEL_ASSERT_PKCS1_KEY_NOT_IMPORTED() ((void) 0)
+#define SCHANNEL_DELETE_PKCS1_KEY() ((void) 0)
+#endif // MONGOC_ENABLE_SSL_SECURE_CHANNEL
+
 static void
 test_x509_auth (void *unused)
 {
@@ -156,7 +268,20 @@ test_x509_auth (void *unused)
       // Try auth:
       bson_error_t error = {0};
       bool ok;
+
+      // Test SChannel key is not previously imported:
       {
+         SCHANNEL_DELETE_PKCS8_KEY ();
+         SCHANNEL_ASSERT_PKCS8_KEY_NOT_IMPORTED ();
+         mongoc_client_t *client = test_framework_client_new_from_uri (uri, NULL); // Imports key.
+         SCHANNEL_ASSERT_PKCS8_KEY_IMPORTED ();
+         ok = try_insert (client, &error);
+         mongoc_client_destroy (client);
+      }
+
+      // Test SChannel key is previously imported:
+      {
+         SCHANNEL_ASSERT_PKCS8_KEY_IMPORTED ();
          mongoc_client_t *client = test_framework_client_new_from_uri (uri, NULL);
          ok = try_insert (client, &error);
          mongoc_client_destroy (client);
@@ -166,8 +291,11 @@ test_x509_auth (void *unused)
       mongoc_uri_destroy (uri);
    }
 
-   // Test auth works:
+   // Test auth works with a PKCS1 key:
    {
+      SCHANNEL_DELETE_PKCS1_KEY ();
+      SCHANNEL_ASSERT_PKCS1_KEY_NOT_IMPORTED ();
+
       // Create URI:
       mongoc_uri_t *uri = get_x509_uri ();
       {
@@ -178,7 +306,19 @@ test_x509_auth (void *unused)
       // Try auth:
       bson_error_t error = {0};
       bool ok;
+      // Test SChannel key is not previously imported:
       {
+         SCHANNEL_DELETE_PKCS1_KEY ();
+         SCHANNEL_ASSERT_PKCS1_KEY_NOT_IMPORTED ();
+         mongoc_client_t *client = test_framework_client_new_from_uri (uri, NULL); // Imports key.
+         SCHANNEL_ASSERT_PKCS1_KEY_IMPORTED ();
+         ok = try_insert (client, &error);
+         mongoc_client_destroy (client);
+      }
+
+      // Test SChannel key is previously imported:
+      {
+         SCHANNEL_ASSERT_PKCS1_KEY_IMPORTED ();
          mongoc_client_t *client = test_framework_client_new_from_uri (uri, NULL);
          ok = try_insert (client, &error);
          mongoc_client_destroy (client);
@@ -346,15 +486,13 @@ test_x509_auth (void *unused)
       bson_error_t error = {0};
       bool ok;
       {
-         mongoc_client_t *client = test_framework_client_new_from_uri (uri, NULL);
          capture_logs (true);
+         mongoc_client_t *client = test_framework_client_new_from_uri (uri, NULL);
          ok = try_insert (client, &error);
-#if defined(MONGOC_ENABLE_SSL_SECURE_TRANSPORT)
+#if defined(MONGOC_ENABLE_SSL_SECURE_TRANSPORT) || defined(MONGOC_ENABLE_SSL_OPENSSL)
          ASSERT_CAPTURED_LOG ("tls", MONGOC_LOG_LEVEL_ERROR, "Cannot find certificate");
 #elif defined(MONGOC_ENABLE_SSL_SECURE_CHANNEL)
          ASSERT_CAPTURED_LOG ("tls", MONGOC_LOG_LEVEL_ERROR, "Failed to open file");
-#elif defined(MONGOC_ENABLE_SSL_OPENSSL)
-         ASSERT_NO_CAPTURED_LOGS ("tls");
 #endif
          mongoc_client_destroy (client);
       }
@@ -437,7 +575,7 @@ test_crl (void *unused)
    bool ok = try_insert (client, &error);
 #ifdef MONGOC_ENABLE_SSL_SECURE_CHANNEL
    remove_crl_for_secure_channel (ssl_opts.crl_file);
-   ASSERT_CAPTURED_LOG ("tls", MONGOC_LOG_LEVEL_ERROR, "Mutual Authentication failed");
+   ASSERT_CAPTURED_LOG ("tls", MONGOC_LOG_LEVEL_ERROR, "The certificate is revoked");
 #else
    ASSERT_NO_CAPTURED_LOGS ("tls");
 #endif
